@@ -1,13 +1,14 @@
 package Data::Clean::ForJSON;
 
 our $DATE = '2019-09-01'; # DATE
-our $VERSION = '0.393'; # VERSION
+our $VERSION = '0.394'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use parent qw(Data::Clean);
+use vars qw($creating_singleton);
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(
@@ -18,6 +19,11 @@ our @EXPORT_OK = qw(
 sub new {
     my ($class, %opts) = @_;
 
+    if (!%opts && !$creating_singleton) {
+        warn "You are creating a new ".__PACKAGE__." object without customizing options. ".
+            "You probably want to call get_cleanser() yet to get a singleton instead?";
+    }
+
     $opts{DateTime}  //= [call_method => 'epoch'];
     $opts{'Time::Moment'} //= [call_method => 'epoch'];
     $opts{'Math::BigInt'} //= [call_method => 'bstr'];
@@ -35,6 +41,7 @@ sub new {
 
 sub get_cleanser {
     my $class = shift;
+    local $creating_singleton = 1;
     state $singleton = $class->new;
     $singleton;
 }
@@ -62,7 +69,7 @@ Data::Clean::ForJSON - Clean data so it is safe to output to JSON
 
 =head1 VERSION
 
-This document describes version 0.393 of Data::Clean::ForJSON (from Perl distribution Data-Clean-ForJSON), released on 2019-09-01.
+This document describes version 0.394 of Data::Clean::ForJSON (from Perl distribution Data-Clean-ForJSON), released on 2019-09-01.
 
 =head1 SYNOPSIS
 
