@@ -1,16 +1,23 @@
 package Data::Clean::FromJSON;
 
 our $DATE = '2019-09-01'; # DATE
-our $VERSION = '0.393'; # VERSION
+our $VERSION = '0.394'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use parent qw(Data::Clean);
+use vars qw($creating_singleton);
 
 sub new {
     my ($class, %opts) = @_;
+
+    if (!%opts && !$creating_singleton) {
+        warn "You are creating a new ".__PACKAGE__." object without customizing options. ".
+            "You probably want to call get_cleanser() yet to get a singleton instead?";
+    }
+
     $opts{"JSON::PP::Boolean"} //= ['deref_scalar_one_or_zero'];
 
     $class->SUPER::new(%opts);
@@ -18,6 +25,7 @@ sub new {
 
 sub get_cleanser {
     my $class = shift;
+    local $creating_singleton = 1;
     state $singleton = $class->new;
     $singleton;
 }
@@ -37,7 +45,7 @@ Data::Clean::FromJSON - Clean data from JSON decoder
 
 =head1 VERSION
 
-This document describes version 0.393 of Data::Clean::FromJSON (from Perl distribution Data-Clean-ForJSON), released on 2019-09-01.
+This document describes version 0.394 of Data::Clean::FromJSON (from Perl distribution Data-Clean-ForJSON), released on 2019-09-01.
 
 =head1 SYNOPSIS
 
